@@ -14,13 +14,13 @@ local({
     hook_output(x, options)
   })
 })
-Sys.setenv(USE_CXX14 = "1")
+Sys.setenv(USE_CXX17 = "1")
 set.seed(12345)
 
 ## -------------------------------------------------------------------------------------------------
 example(stanFunction, package = "StanHeaders", run.dontrun = TRUE)
 
-## ---- echo = FALSE, warning = FALSE, class.output="scroll-100"------------------------------------
+## ----echo = FALSE, warning = FALSE, class.output="scroll-100"-------------------------------------
 if (length(functions) %% 2 == 1) {
   functions <- c(functions, "")
 }
@@ -39,7 +39,7 @@ Sys.setenv(PKG_LIBS = paste0(StanHeaders:::LdFlags(as_character = TRUE),
 x <- optim(rnorm(3), fn = f, gr = g, a = 1:3, method = "BFGS", hessian = TRUE)
 x$par
 x$hessian
-#H(x$par, a = 1:3)
+H(x$par, a = 1:3)
 J(x$par, a = 1:3)
 solution(a = 1:3, guess = rnorm(3))
 
@@ -59,10 +59,13 @@ Sys.setenv(STAN_NUM_THREADS = 2) # specify -1 to use all available cores
 odd <- seq.int(from = 2^25 - 1, to = 2^26 - 1, by = 2)
 tail(psapply(n = as.list(odd))) == 1 # check your process manager while this is running
 
-## ---- echo = FALSE, comment = ""------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
+stopifnot(all.equal(1, check_logarithmic_PMF(p = 1 / sqrt(2))))
+
+## ----echo = FALSE, comment = ""-------------------------------------------------------------------
 cat(readLines("sparselm_stan.hpp"), sep = "\n")
 
-## ---- message = FALSE-----------------------------------------------------------------------------
+## ----message = FALSE------------------------------------------------------------------------------
 library(Rcpp)
 tf <- tempfile(fileext = "Module.cpp")
 exposeClass("sparselm_stan",
@@ -75,7 +78,7 @@ exposeClass("sparselm_stan",
                  "// [[Rcpp::depends(RcppEigen)]]",
                  "// [[Rcpp::depends(RcppParallel)]",
                  "// [[Rcpp::depends(StanHeaders)]]",
-                 "// [[Rcpp::plugins(cpp14)]]",
+                 "// [[Rcpp::plugins(cpp17)]]",
                  paste0("#include <", file.path(getwd(), "sparselm_stan.hpp"), ">")),
       file = tf,
       Rfile = FALSE)
