@@ -9,10 +9,16 @@
 #include <stan/math/fwd/core/operator_greater_than_or_equal.hpp>
 #include <stan/math/fwd/core/operator_less_than.hpp>
 #include <stan/math/fwd/core/operator_less_than_or_equal.hpp>
+#include <stan/math/fwd/core/operator_logical_and.hpp>
+#include <stan/math/fwd/core/operator_logical_or.hpp>
 #include <stan/math/fwd/core/operator_multiplication.hpp>
 #include <stan/math/fwd/core/operator_not_equal.hpp>
 #include <stan/math/fwd/core/operator_subtraction.hpp>
 #include <stan/math/fwd/core/operator_unary_minus.hpp>
+#include <stan/math/fwd/core/operator_unary_not.hpp>
+#include <stan/math/fwd/core/operator_unary_plus.hpp>
+#include <stan/math/fwd/core/std_complex.hpp>
 #include <stan/math/fwd/core/std_numeric_limits.hpp>
+#include <stan/math/fwd/core/std_iterator_traits.hpp>
 
 #endif
