@@ -20,13 +20,9 @@ template <typename T,
 inline var_value<matrix_cl<double>> Phi(const var_value<T>& A) {
   return make_callback_var(
       Phi(A.val()), [A](vari_value<matrix_cl<double>>& res) mutable {
-        A.adj()
-            = A.adj()
-              + elt_multiply(
-                    res.adj(),
-                    elt_multiply(INV_SQRT_TWO_PI,
-                                 exp(elt_multiply(
-                                     -0.5, elt_multiply(A.val(), A.val())))));
+        A.adj() += elt_multiply(
+            res.adj(), elt_multiply(INV_SQRT_TWO_PI,
+                                    exp(elt_multiply(-0.5, square(A.val())))));
       });
 }
 
