@@ -10,18 +10,6 @@
 namespace stan {
 namespace math {
 
-namespace internal {
-class trunc_vari : public op_v_vari {
- public:
-  explicit trunc_vari(vari* avi) : op_v_vari(trunc(avi->val_), avi) {}
-  void chain() {
-    if (unlikely(is_nan(avi_->val_))) {
-      avi_->adj_ = NOT_A_NUMBER;
-    }
-  }
-};
-}  // namespace internal
-
 /**
  * Returns the truncation of the specified variable (C99).
  *
@@ -52,7 +40,7 @@ class trunc_vari : public op_v_vari {
  * @param a Specified variable.
  * @return Truncation of the variable.
  */
-inline var trunc(const var& a) { return var(new internal::trunc_vari(a.vi_)); }
+inline var trunc(const var& a) { return var(trunc(a.val())); }
 
 }  // namespace math
 }  // namespace stan
