@@ -1,13 +1,9 @@
-/*
- * -----------------------------------------------------------------
- * $Revision$
- * $Date$
- * -----------------------------------------------------------------
+/* -----------------------------------------------------------------
  * Programmer(s): Allan Taylor, Alan Hindmarsh, Radu Serban, and
- *                Aaron Collier @ LLNL
+ *                Aaron Collier, Shelby Lockhart @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * Copyright (c) 2002-2022, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -38,18 +34,13 @@
 #define TWO       RCONST(2.0)
 #define TWOPT5    RCONST(2.5)
 
-#define liw  (kin_mem->kin_liw)
-#define lrw  (kin_mem->kin_lrw)
-#define liw1 (kin_mem->kin_liw1)
-#define lrw1 (kin_mem->kin_lrw1)
-
-/* 
+/*
  * =================================================================
  * KINSOL optional input functions
  * =================================================================
  */
 
-/* 
+/*
  * -----------------------------------------------------------------
  * KINSetErrHandlerFn
  * -----------------------------------------------------------------
@@ -93,8 +84,6 @@ int KINSetErrFile(void *kinmem, FILE *errfp)
   return(KIN_SUCCESS);
 }
 
-#define errfp (kin_mem->kin_errfp)
-
 /*
  * -----------------------------------------------------------------
  * Function : KINSetPrintLevel
@@ -122,7 +111,7 @@ int KINSetPrintLevel(void *kinmem, int printfl)
   return(KIN_SUCCESS);
 }
 
-/* 
+/*
  * -----------------------------------------------------------------
  * KINSetInfoHandlerFn
  * -----------------------------------------------------------------
@@ -167,6 +156,40 @@ int KINSetInfoFile(void *kinmem, FILE *infofp)
   return(KIN_SUCCESS);
 }
 
+
+/*
+ * -----------------------------------------------------------------
+ * Function : KINSetDebugFile
+ * -----------------------------------------------------------------
+ */
+
+int KINSetDebugFile(void *kinmem, FILE *debugfp)
+{
+  KINMem kin_mem;
+
+  if (kinmem == NULL) {
+    KINProcessError(NULL, KIN_MEM_NULL, "KINSOL", "KINSetDebugFile",
+                    MSG_NO_MEM);
+    return(KIN_MEM_NULL);
+  }
+
+  kin_mem = (KINMem) kinmem;
+
+#if defined(SUNDIALS_DEBUG)
+  if (debugfp)
+    kin_mem->kin_debugfp = debugfp;
+  else
+    kin_mem->kin_debugfp = stdout;
+
+  return(KIN_SUCCESS);
+#else
+  KINProcessError(kin_mem, KIN_ILL_INPUT, "KINSOL", "KINSetDebugFile",
+                  "SUNDIALS was not built with debugging enabled");
+  return(KIN_ILL_INPUT);
+#endif
+}
+
+
 /*
  * -----------------------------------------------------------------
  * Function : KINSetUserData
@@ -188,6 +211,44 @@ int KINSetUserData(void *kinmem, void *user_data)
   return(KIN_SUCCESS);
 }
 
+/*
+ * -----------------------------------------------------------------
+ * Function : KINSetDamping
+ * -----------------------------------------------------------------
+ */
+
+int KINSetDamping(void *kinmem, realtype beta)
+{
+  KINMem kin_mem;
+
+  if (kinmem == NULL) {
+    KINProcessError(NULL, KIN_MEM_NULL, "KINSOL", "KINSetDamping", MSG_NO_MEM);
+    return(KIN_MEM_NULL);
+  }
+
+  kin_mem = (KINMem) kinmem;
+
+  /* check for illegal input value */
+  if (beta <= ZERO) {
+    KINProcessError(NULL, KIN_ILL_INPUT, "KINSOL", "KINSetDamping",
+                    "beta <= 0 illegal");
+    return(KIN_ILL_INPUT);
+  }
+
+  if (beta < ONE) {
+    /* enable damping */
+    kin_mem->kin_beta    = beta;
+    kin_mem->kin_damping = SUNTRUE;
+  } else {
+    /* disable damping */
+    kin_mem->kin_beta    = ONE;
+    kin_mem->kin_damping = SUNFALSE;
+  }
+
+  return(KIN_SUCCESS);
+}
+
+
 /*
  * -----------------------------------------------------------------
  * Function : KINSetMAA
@@ -212,36 +273,127 @@ int KINSetMAA(void *kinmem, long int maa)
 
   if (maa > kin_mem->kin_mxiter) maa = kin_mem->kin_mxiter;
 
-  kin_mem = (KINMem) kinmem;
   kin_mem->kin_m_aa = maa;
-  kin_mem->kin_aamem_aa = (maa == 0) ? SUNFALSE : SUNTRUE;
+
+  return(KIN_SUCCESS);
+}
+
+
+/*
+ * -----------------------------------------------------------------
+ * Function : KINSetDelayAA
+ * -----------------------------------------------------------------
+ */
+
+int KINSetDelayAA(void *kinmem, long int delay)
+{
+  KINMem kin_mem;
+
+  if (kinmem == NULL) {
+    KINProcessError(NULL, KIN_MEM_NULL, "KINSOL", "KINSetDelayAA", MSG_NO_MEM);
+    return(KIN_MEM_NULL);
+  }
+
+  kin_mem = (KINMem) kinmem;
+
+  /* check for illegal input value */
+  if (delay < 0) {
+    KINProcessError(NULL, KIN_ILL_INPUT, "KINSOL", "KINSetDelayAA",
+                    "delay < 0 illegal");
+    return(KIN_ILL_INPUT);
+  }
+
+  kin_mem->kin_delay_aa = delay;
+
+  return(KIN_SUCCESS);
+}
+
+
+/*
+ * -----------------------------------------------------------------
+ * Function : KINSetOrthAA
+ * -----------------------------------------------------------------
+ */
+
+int KINSetOrthAA(void *kinmem, int orthaa)
+{
+  KINMem kin_mem;
+
+  if (kinmem == NULL) {
+    KINProcessError(NULL, KIN_MEM_NULL, "KINSOL", "KINSetOrthAA", MSG_NO_MEM);
+    return(KIN_MEM_NULL);
+  }
+
+  kin_mem = (KINMem) kinmem;
+
+  if ((orthaa < KIN_ORTH_MGS) || (orthaa > KIN_ORTH_DCGS2)) {
+    KINProcessError(kin_mem, KIN_ILL_INPUT, "KINSOL", "KINSetOrthAA", MSG_BAD_ORTHAA);
+    return(KIN_ILL_INPUT);
+  }
+
+  kin_mem->kin_orth_aa = orthaa;
 
   return(KIN_SUCCESS);
 }
 
 /*
  * -----------------------------------------------------------------
- * Function : KINSetAAStopCrit
+ * Function : KINSetDampingAA
  * -----------------------------------------------------------------
  */
 
-/*  CSW: This function is currently not supported.
-
-int KINSetAAStopCrit(void *kinmem, booleantype setstop)
+int KINSetDampingAA(void *kinmem, realtype beta)
 {
   KINMem kin_mem;
 
   if (kinmem == NULL) {
-    KINProcessError(NULL, KIN_MEM_NULL, "KINSOL", "KINSetAAStopCrit", MSG_NO_MEM);
+    KINProcessError(NULL, KIN_MEM_NULL, "KINSOL", "KINSetDampingAA", MSG_NO_MEM);
     return(KIN_MEM_NULL);
   }
 
   kin_mem = (KINMem) kinmem;
-  kin_mem->kin_setstop_aa = setstop;
+
+  /* check for illegal input value */
+  if (beta <= ZERO) {
+    KINProcessError(NULL, KIN_ILL_INPUT, "KINSOL", "KINSetDampingAA",
+                    "beta <= 0 illegal");
+    return(KIN_ILL_INPUT);
+  }
+
+  if (beta < ONE) {
+    /* enable damping */
+    kin_mem->kin_beta_aa    = beta;
+    kin_mem->kin_damping_aa = SUNTRUE;
+  } else {
+    /* disable damping */
+    kin_mem->kin_beta_aa    = ONE;
+    kin_mem->kin_damping_aa = SUNFALSE;
+  }
+
+  return(KIN_SUCCESS);
+}
+
+/*
+ * -----------------------------------------------------------------
+ * Function : KINSetReturnNewest
+ * -----------------------------------------------------------------
+ */
+
+int KINSetReturnNewest(void *kinmem, booleantype ret_newest)
+{
+  KINMem kin_mem;
+
+  if (kinmem == NULL) {
+    KINProcessError(NULL, KIN_MEM_NULL, "KINSOL", "KINSetReturnNewest", MSG_NO_MEM);
+    return(KIN_MEM_NULL);
+  }
+
+  kin_mem = (KINMem) kinmem;
+
+  kin_mem->kin_ret_newest = ret_newest;
 
   return(KIN_SUCCESS);
 }
-*/
 
 /*
  * -----------------------------------------------------------------
@@ -336,7 +488,7 @@ int KINSetMaxSetupCalls(void *kinmem, long int msbset)
     KINProcessError(NULL, KIN_ILL_INPUT, "KINSOL", "KINSetMaxSetupCalls", MSG_BAD_MSBSET);
     return(KIN_ILL_INPUT);
   }
-  
+
   if (msbset == 0)
     kin_mem->kin_msbset = MSBSET_DEFAULT;
   else
@@ -366,7 +518,7 @@ int KINSetMaxSubSetupCalls(void *kinmem, long int msbsetsub)
     KINProcessError(NULL, KIN_ILL_INPUT, "KINSOL", "KINSetMaxSubSetupCalls", MSG_BAD_MSBSETSUB);
     return(KIN_ILL_INPUT);
   }
-  
+
   if (msbsetsub == 0)
     kin_mem->kin_msbset_sub = MSBSET_SUB_DEFAULT;
   else
@@ -392,8 +544,8 @@ int KINSetEtaForm(void *kinmem, int etachoice)
 
   kin_mem = (KINMem) kinmem;
 
-  if ((etachoice != KIN_ETACONSTANT) && 
-      (etachoice != KIN_ETACHOICE1)  && 
+  if ((etachoice != KIN_ETACONSTANT) &&
+      (etachoice != KIN_ETACHOICE1)  &&
       (etachoice != KIN_ETACHOICE2)) {
     KINProcessError(NULL, KIN_ILL_INPUT, "KINSOL", "KINSetEtaForm", MSG_BAD_ETACHOICE);
     return(KIN_ILL_INPUT);
@@ -456,8 +608,8 @@ int KINSetEtaParams(void *kinmem, realtype egamma, realtype ealpha)
       KINProcessError(NULL, KIN_ILL_INPUT, "KINSOL", "KINSetEtaParams", MSG_BAD_ALPHA);
       return(KIN_ILL_INPUT);
     }
-  
-  if (ealpha == ZERO) 
+
+  if (ealpha == ZERO)
     kin_mem->kin_eta_alpha = TWO;
   else
     kin_mem->kin_eta_alpha = ealpha;
@@ -500,7 +652,7 @@ int KINSetResMonParams(void *kinmem, realtype omegamin, realtype omegamax)
     return(KIN_ILL_INPUT);
   }
 
-  if (omegamin == ZERO) 
+  if (omegamin == ZERO)
     kin_mem->kin_omega_min = OMEGA_MIN;
   else
     kin_mem->kin_omega_min = omegamin;
@@ -765,8 +917,8 @@ int KINSetConstraints(void *kinmem, N_Vector constraints)
   if (constraints == NULL) {
     if (kin_mem->kin_constraintsSet) {
       N_VDestroy(kin_mem->kin_constraints);
-      lrw -= lrw1;
-      liw -= liw1;
+      kin_mem->kin_lrw -= kin_mem->kin_lrw1;
+      kin_mem->kin_liw -= kin_mem->kin_liw1;
     }
     kin_mem->kin_constraintsSet = SUNFALSE;
     return(KIN_SUCCESS);
@@ -775,15 +927,15 @@ int KINSetConstraints(void *kinmem, N_Vector constraints)
   /* Check the constraints vector */
 
   temptest = N_VMaxNorm(constraints);
-  if (temptest > TWOPT5){ 
+  if (temptest > TWOPT5){
     KINProcessError(NULL, KIN_ILL_INPUT, "KINSOL", "KINSetConstraints", MSG_BAD_CONSTRAINTS);
-    return(KIN_ILL_INPUT); 
+    return(KIN_ILL_INPUT);
   }
 
   if (!kin_mem->kin_constraintsSet) {
     kin_mem->kin_constraints = N_VClone(constraints);
-    lrw += lrw1;
-    liw += liw1;
+    kin_mem->kin_lrw += kin_mem->kin_lrw1;
+    kin_mem->kin_liw += kin_mem->kin_liw1;
     kin_mem->kin_constraintsSet = SUNTRUE;
   }
 
@@ -821,24 +973,10 @@ int KINSetSysFunc(void *kinmem, KINSysFn func)
   return(KIN_SUCCESS);
 }
 
-/* 
- * =================================================================
- * Readability constants
- * =================================================================
- */
 
-#define nni (kin_mem->kin_nni)
-#define nfe (kin_mem->kin_nfe)
-#define nbcf (kin_mem->kin_nbcf)  
-#define nbktrk (kin_mem->kin_nbktrk)
-#define stepl (kin_mem->kin_stepl)
-#define fnorm (kin_mem->kin_fnorm)
-#define liw (kin_mem->kin_liw)
-#define lrw (kin_mem->kin_lrw)
-
-/* 
+/*
  * =================================================================
- * KINSOL optional input functions
+ * KINSOL optional output functions
  * =================================================================
  */
 
@@ -859,8 +997,8 @@ int KINGetWorkSpace(void *kinmem, long int *lenrw, long int *leniw)
 
   kin_mem = (KINMem) kinmem;
 
-  *lenrw = lrw;
-  *leniw = liw;
+  *lenrw = kin_mem->kin_lrw;
+  *leniw = kin_mem->kin_liw;
 
   return(KIN_SUCCESS);
 }
@@ -881,7 +1019,7 @@ int KINGetNumNonlinSolvIters(void *kinmem, long int *nniters)
   }
 
   kin_mem = (KINMem) kinmem;
-  *nniters = nni;
+  *nniters = kin_mem->kin_nni;
 
   return(KIN_SUCCESS);
 }
@@ -902,7 +1040,7 @@ int KINGetNumFuncEvals(void *kinmem, long int *nfevals)
   }
 
   kin_mem = (KINMem) kinmem;
-  *nfevals = nfe;
+  *nfevals = kin_mem->kin_nfe;
 
   return(KIN_SUCCESS);
 }
@@ -923,7 +1061,7 @@ int KINGetNumBetaCondFails(void *kinmem, long int *nbcfails)
   }
 
   kin_mem = (KINMem) kinmem;
-  *nbcfails = nbcf;
+  *nbcfails = kin_mem->kin_nbcf;
 
   return(KIN_SUCCESS);
 }
@@ -944,7 +1082,7 @@ int KINGetNumBacktrackOps(void *kinmem, long int *nbacktr)
   }
 
   kin_mem = (KINMem) kinmem;
-  *nbacktr = nbktrk;
+  *nbacktr = kin_mem->kin_nbktrk;
 
   return(KIN_SUCCESS);
 }
@@ -986,7 +1124,7 @@ int KINGetStepLength(void *kinmem, realtype *steplength)
   }
 
   kin_mem = (KINMem) kinmem;
-  *steplength = stepl;
+  *steplength = kin_mem->kin_stepl;
 
   return(KIN_SUCCESS);
 }
